@@ -1,54 +1,51 @@
-/***************************************************************************
- *   This file is part of the KDE project                                  *
- *                                                                         *
- *   Copyright (C) 2010 Alejandro Fiestas Olivares <alex@ufocoders.com>    *
- *   Copyright (C) 2010 UFO Coders <info@ufocoders.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*****************************************************************************
+ * This file is part of the KDE project                                      *
+ *                                                                           *
+ * Copyright (C) 2010-2011 Alejandro Fiestas Olivares <afiestas@kde.org>     *
+ * Copyright (C) 2010-2011 UFO Coders <info@ufocoders.com>                   *
+ *                                                                           *
+ * This library is free software; you can redistribute it and/or             *
+ * modify it under the terms of the GNU Library General Public               *
+ * License as published by the Free Software Foundation; either              *
+ * version 2 of the License, or (at your option) any later version.          *
+ *                                                                           *
+ * This library is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
+ * Library General Public License for more details.                          *
+ *                                                                           *
+ * You should have received a copy of the GNU Library General Public License *
+ * along with this library; see the file COPYING.LIB.  If not, write to      *
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
+ * Boston, MA 02110-1301, USA.                                               *
+ *****************************************************************************/
 
 #include "sendfilesjob.h"
 #include "obexagent.h"
 #include "obex_transfer.h"
-
 #include "obex_client.h"
 
-#include <KFileItemList>
 #include <KLocalizedString>
 #include <KDebug>
 
 #include <bluedevil/bluedevil.h>
 
 using namespace BlueDevil;
-SendFilesJob::SendFilesJob(KFileItemList list, Device *device, ObexAgent *agent, QObject* parent): KJob(parent)
+SendFilesJob::SendFilesJob(const QStringList& files, Device* device, ObexAgent* agent, QObject* parent): KJob(parent)
 ,m_currentTransferJob(0)
 {
+    m_filesToSend = files;
     m_agent = agent;
     m_device = device;
 
     m_totalSize = 0;
     m_progress = 0;
 
-    Q_FOREACH(const KFileItem &item, list) {
-        if (item.isLocalFile()) {
-            m_filesToSend << item.url().path();
-            kDebug() << "Adding size : " << item.size();
-            m_filesToSendSize << item.size();
-            m_totalSize += item.size();
-        }
+    Q_FOREACH(const QString &filePath, files) {
+        QFile file(filePath);
+        kDebug() << "Adding size : " << file.size();
+        m_filesToSendSize << file.size();
+        m_totalSize += file.size();
     }
 
     connect(m_agent, SIGNAL(request(OrgOpenobexTransferInterface *)), this, SLOT(nextJob(OrgOpenobexTransferInterface*)));
@@ -115,7 +112,7 @@ void SendFilesJob::nextJob(OrgOpenobexTransferInterface *transferObj)
     m_currentFileSize = m_filesToSendSize.takeFirst();
     m_currentTransferJob = transferObj;
 
-    emit description(this, i18n("Sending file over bluetooth"), QPair<QString, QString>(i18nc("File transfer origin", "From"), m_currentFile), QPair<QString, QString>(i18nc("File transfer destination", "To"), m_device->name()));
+    emit description(this, i18n("Sending file over Bluetooth"), QPair<QString, QString>(i18nc("File transfer origin", "From"), m_currentFile), QPair<QString, QString>(i18nc("File transfer destination", "To"), m_device->name()));
 }
 
 void SendFilesJob::jobDone(QDBusObjectPath transfer)
