@@ -24,20 +24,29 @@
 #include "bluedevil_service_interface.h"
 #include "filereceiversettings.h"
 
+#include <QDBusMetaType>
+
 #include <kdemacros.h>
 #include <KDebug>
 #include <KAboutData>
 #include <KPluginFactory>
 #include <kfileplacesmodel.h>
 #include <kprocess.h>
+#include <kdirnotify.h>
 
 #include <bluedevil/bluedevilmanager.h>
 #include <bluedevil/bluedeviladapter.h>
+#include <bluedevil/bluedevildevice.h>
+
+using namespace BlueDevil;
 
 K_PLUGIN_FACTORY(BlueDevilFactory,
                  registerPlugin<BlueDevilDaemon>();)
 K_EXPORT_PLUGIN(BlueDevilFactory("bluedevildaemon", "bluedevil"))
 
+Q_DECLARE_METATYPE(DeviceInfo)
+Q_DECLARE_METATYPE(QMapDeviceInfo)
+
 struct BlueDevilDaemon::Private
 {
     enum Status {
@@ -47,18 +56,25 @@ struct BlueDevilDaemon::Private
 
     AgentListener                   *m_agentListener;
     KFilePlacesModel                *m_placesModel;
-    BlueDevil::Adapter              *m_adapter;
+    Adapter                         *m_adapter;
     org::kde::BlueDevil::Service    *m_service;
+    QList <DeviceInfo>                m_discovered;
+    QTimer                           m_timer;
 };
 
 BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
     : KDEDModule(parent)
     , d(new Private)
 {
+    qDBusRegisterMetaType <DeviceInfo> ();
+    qDBusRegisterMetaType <QMapDeviceInfo> ();
+
     d->m_agentListener = 0;
     d->m_adapter = 0;
     d->m_service = 0;
     d->m_placesModel = 0;
+    d->m_timer.setInterval(20000);
+    d->m_timer.setSingleShot(true);
 
     KAboutData aboutData(
         "bluedevildaemon",
@@ -76,11 +92,14 @@ BlueDevilDaemon::BlueDevilDaemon(QObject *parent, const QList<QVariant>&)
     aboutData.addAuthor(ki18n("Eduardo Robles Elvira"), ki18n("Maintainer"), "edulix@gmail.com",
         "http://blog.edulix.es");
 
-    connect(BlueDevil::Manager::self(), SIGNAL(defaultAdapterChanged(Adapter*)),
+    connect(Manager::self(), SIGNAL(defaultAdapterChanged(Adapter*)),
             this, SLOT(defaultAdapterChanged(Adapter*)));
 
+    connect(Manager::self()->defaultAdapter(), SIGNAL(deviceFound(Device*)), this, SLOT(deviceFound(Device*)));
+    connect(&d->m_timer, SIGNAL(timeout()), Manager::self()->defaultAdapter(), SLOT(stopDiscovery()));
+
     d->m_status = Private::Offline;
-    if (BlueDevil::Manager::self()->defaultAdapter()) {
+    if (Manager::self()->defaultAdapter()) {
         onlineMode();
     }
 }
@@ -94,6 +113,50 @@ BlueDevilDaemon::~BlueDevilDaemon()
     delete d;
 }
 
+bool BlueDevilDaemon::isOnline()
+{
+    if (d->m_status == Private::Offline) {
+        return false;
+    }
+    return true;
+}
+
+QMapDeviceInfo BlueDevilDaemon::knownDevices()
+{
+    QMapDeviceInfo devices;
+
+    QList <Device* > list = Manager::self()->defaultAdapter()->devices();
+    kDebug() << "List: " << list.length();
+    DeviceInfo info;
+    Q_FOREACH(const Device* device, list) {
+        info["name"] = device->friendlyName();
+        info["icon"] = device->icon();
+        info["address"] = device->address();
+        devices[device->address()] = info;
+    }
+
+    if (!d->m_timer.isActive()) {
+        kDebug() << "Start Discovery";
+        Manager::self()->defaultAdapter()->startStableDiscovery();
+        d->m_discovered.clear();
+        d->m_timer.start();
+    }
+
+    Q_FOREACH(const DeviceInfo& info, d->m_discovered) {
+        if (!devices.contains(info["address"])) {
+            devices[info["address"]] = info;
+        }
+    }
+    return devices;
+}
+
+void BlueDevilDaemon::stopDiscovering()
+{
+    kDebug() << "Stopping discovering";
+    d->m_timer.stop();
+    Manager::self()->defaultAdapter()->stopDiscovery();
+}
+
 bool BlueDevilDaemon::isServiceStarted()
 {
     if (!d->m_service) {
@@ -120,7 +183,7 @@ void BlueDevilDaemon::onlineMode()
     connect(d->m_agentListener, SIGNAL(agentReleased()), this, SLOT(agentReleased()));
     d->m_agentListener->start();
 
-    d->m_adapter = BlueDevil::Manager::self()->defaultAdapter();
+    d->m_adapter = Manager::self()->defaultAdapter();
 
     FileReceiverSettings::self()->readConfig();
     if (!isServiceStarted() && FileReceiverSettings::self()->enabled()) {
@@ -206,7 +269,7 @@ void BlueDevilDaemon::agentThreadStopped()
     kDebug() << "agent listener deleted";
 }
 
-void BlueDevilDaemon::defaultAdapterChanged(BlueDevil::Adapter *adapter)
+void BlueDevilDaemon::defaultAdapterChanged(Adapter *adapter)
 {
     //if we have an adapter, remove it and offline the KDED for a moment
     if (d->m_adapter) {
@@ -219,3 +282,21 @@ void BlueDevilDaemon::defaultAdapterChanged(BlueDevil::Adapter *adapter)
         onlineMode();
     }
 }
+
+void BlueDevilDaemon::deviceFound(Device *device)
+{
+    kDebug() << "DeviceFound: " << device->name();
+    d->m_discovered.append(deviceToInfo(device));
+    org::kde::KDirNotify::emitFilesAdded("bluetooth:/");
+}
+
+DeviceInfo BlueDevilDaemon::deviceToInfo(const Device* device) const
+{
+    DeviceInfo info;
+    info["name"] = device->friendlyName();
+    info["icon"] = device->icon();
+    info["address"] = device->address();
+    info["discovered"] = "true";
+
+    return info;
+}
\ No newline at end of file
